Struct ZwlrDataControlSourceV1
pub struct ZwlrDataControlSourceV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
offer to transfer data
The wlr_data_control_source object is the source side of a wlr_data_control_offer. It is created by the source client in a data transfer and provides a way to describe the offered data and a way to respond to requests to transfer the data.
See also the Request enum for this interface.
Implementations
impl ZwlrDataControlSourceV1
impl ZwlrDataControlSourceV1
pub fn send(&self, mime_type: String, fd: BorrowedFd<'_>)
pub fn send(&self, mime_type: String, fd: BorrowedFd<'_>)
send the data
Request for data from the client. Send the data as the specified MIME type over the passed file descriptor, then close it.
pub fn cancelled(&self)
pub fn cancelled(&self)
selection was cancelled
This data source is no longer valid. The data source has been replaced by another data source.
The client should clean up and destroy this data source.